/*******************************************************************************
* Copyright 2020 Intel Corporation
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
*     http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*******************************************************************************/

#pragma once

#include <daal/include/algorithms/decision_forest/decision_forest_classification_predict_types.h>
#include <daal/include/algorithms/decision_forest/decision_forest_classification_training_types.h>
#include <daal/include/algorithms/decision_forest/decision_forest_regression_predict_types.h>
#include <daal/include/algorithms/decision_forest/decision_forest_regression_training_types.h>

#include "oneapi/dal/algo/decision_forest/common.hpp"

namespace oneapi::dal::decision_forest::backend {

inline auto convert_to_daal_voting_mode(voting_mode vm) {
    namespace daal_df_cls = daal::algorithms::decision_forest::classification;
    return voting_mode::weighted == vm ? daal_df_cls::prediction::weighted
                                       : daal_df_cls::prediction::unweighted;
}

inline auto convert_to_daal_variable_importance_mode(variable_importance_mode vimp) {
    namespace daal_df = daal::algorithms::decision_forest;
    return variable_importance_mode::mdi == vimp
               ? daal_df::training::MDI
               : variable_importance_mode::mda_raw == vimp
                     ? daal_df::training::MDA_Raw
                     : variable_importance_mode::mda_scaled == vimp ? daal_df::training::MDA_Scaled
                                                                    : daal_df::training::none;
}

class model_interop : public base {
public:
    virtual ~model_interop() = default;
    virtual void clear() {}
};

template <typename DaalModel>
class model_interop_impl : public model_interop {
public:
    model_interop_impl(const DaalModel& model) : daal_model_(model) {}

    const DaalModel get_model() const {
        return daal_model_;
    }

    void clear() override {
        daal_model_->clear();
    }

private:
    DaalModel daal_model_;
};

using model_interop_cls =
    model_interop_impl<daal::algorithms::decision_forest::classification::ModelPtr>;

using model_interop_reg =
    model_interop_impl<daal::algorithms::decision_forest::regression::ModelPtr>;

} // namespace oneapi::dal::decision_forest::backend
