/* file: online.cpp */
/*******************************************************************************
* Copyright 2014-2020 Intel Corporation
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
*     http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*******************************************************************************/

#include <jni.h>
#include "com_intel_daal_algorithms_svd_Online.h"

#include "com/intel/daal/common_helpers.h"

USING_COMMON_NAMESPACES()
using namespace daal::algorithms::svd;

/*
 * Class:     com_intel_daal_algorithms_svd_Online
 * Method:    cInitOnline
 * Signature:(II)J
 */
JNIEXPORT jlong JNICALL Java_com_intel_daal_algorithms_svd_Online_cInitOnline(JNIEnv * env, jobject thisObj, jint prec, jint method)
{
    return jniOnline<svd::Method, Online, defaultDense>::newObj(prec, method);
}

/*
 * Class:     com_intel_daal_algorithms_svd_Online
 * Method:    cInitParameter
 * Signature:(JII)J
 */
JNIEXPORT jlong JNICALL Java_com_intel_daal_algorithms_svd_Online_cInitParameter(JNIEnv * env, jobject thisObj, jlong algAddr, jint prec, jint method)
{
    return jniOnline<svd::Method, Online, defaultDense>::getParameter(prec, method, algAddr);
}

/*
 * Class:     com_intel_daal_algorithms_svd_Online
 * Method:    cInput
 * Signature:(JII)J
 */
JNIEXPORT jlong JNICALL Java_com_intel_daal_algorithms_svd_Online_cGetInput(JNIEnv * env, jobject thisObj, jlong algAddr, jint prec, jint method)
{
    return jniOnline<svd::Method, Online, defaultDense>::getInput(prec, method, algAddr);
}

/*
 * Class:     com_intel_daal_algorithms_svd_Online
 * Method:    cGetResult
 * Signature:(JII)J
 */
JNIEXPORT jlong JNICALL Java_com_intel_daal_algorithms_svd_Online_cGetResult(JNIEnv * env, jobject thisObj, jlong algAddr, jint prec, jint method)
{
    return jniOnline<svd::Method, Online, defaultDense>::getResult(prec, method, algAddr);
}

/*
 * Class:     com_intel_daal_algorithms_svd_Online
 * Method:    cGetPartial
 * Signature:(JII)J
 */
JNIEXPORT jlong JNICALL Java_com_intel_daal_algorithms_svd_Online_cGetPartialResult(JNIEnv * env, jobject thisObj, jlong algAddr, jint prec,
                                                                                    jint method)
{
    return jniOnline<svd::Method, Online, defaultDense>::getPartialResult(prec, method, algAddr);
}

/*
 * Class:     com_intel_daal_algorithms_svd_Online
 * Method:    cSetResult
 * Signature: (JIIJ)V
 */
JNIEXPORT void JNICALL Java_com_intel_daal_algorithms_svd_Online_cSetResult(JNIEnv * env, jobject thisObj, jlong algAddr, jint prec, jint method,
                                                                            jlong resultAddr)
{
    jniOnline<svd::Method, Online, defaultDense>::setResult<svd::Result>(prec, method, algAddr, resultAddr);
}

/*
 * Class:     com_intel_daal_algorithms_svd_Online
 * Method:    cSetPartialResult
 * Signature: (JIIJ)V
 */
JNIEXPORT void JNICALL Java_com_intel_daal_algorithms_svd_Online_cSetPartialResult(JNIEnv * env, jobject thisObj, jlong algAddr, jint prec,
                                                                                   jint method, jlong partialResultAddr, jboolean initFlag)
{
    jniOnline<svd::Method, Online, defaultDense>::setPartialResult<svd::OnlinePartialResult>(prec, method, algAddr, partialResultAddr);
}

/*
 * Class:     com_intel_daal_algorithms_svd_Online
 * Method:    cClone
 * Signature:(JII)J
 */
JNIEXPORT jlong JNICALL Java_com_intel_daal_algorithms_svd_Online_cClone(JNIEnv * env, jobject thisObj, jlong algAddr, jint prec, jint method)
{
    return jniOnline<svd::Method, Online, defaultDense>::getClone(prec, method, algAddr);
}
